/****************************************************************************
** Meta object code from reading C++ file 'declarativebars_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../qtdatavis3d/src/datavisualizationqml/declarativebars_p.h"
#include <QtDataVisualization/q3dscene.h>
#include <QtDataVisualization/qbar3dseries.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'declarativebars_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15DeclarativeBarsE_t {};
} // unnamed namespace

template <> constexpr inline auto DeclarativeBars::qt_create_metaobjectdata<qt_meta_tag_ZN15DeclarativeBarsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DeclarativeBars",
        "DefaultProperty",
        "seriesList",
        "QML.Element",
        "Bars3D",
        "QML.AddedInVersion",
        "256",
        "rowAxisChanged",
        "",
        "QCategory3DAxis*",
        "axis",
        "valueAxisChanged",
        "QValue3DAxis*",
        "columnAxisChanged",
        "multiSeriesUniformChanged",
        "uniform",
        "barThicknessChanged",
        "thicknessRatio",
        "barSpacingChanged",
        "QSizeF",
        "spacing",
        "barSpacingRelativeChanged",
        "relative",
        "barSeriesMarginChanged",
        "margin",
        "meshFileNameChanged",
        "filename",
        "primarySeriesChanged",
        "QBar3DSeries*",
        "series",
        "selectedSeriesChanged",
        "floorLevelChanged",
        "level",
        "handleAxisXChanged",
        "QAbstract3DAxis*",
        "handleAxisYChanged",
        "handleAxisZChanged",
        "addSeries",
        "removeSeries",
        "insertSeries",
        "index",
        "rowAxis",
        "valueAxis",
        "columnAxis",
        "multiSeriesUniform",
        "barThickness",
        "barSpacing",
        "barSpacingRelative",
        "barSeriesMargin",
        "QQmlListProperty<QBar3DSeries>",
        "selectedSeries",
        "primarySeries",
        "floorLevel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'rowAxisChanged'
        QtMocHelpers::SignalData<void(QCategory3DAxis *)>(7, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'valueAxisChanged'
        QtMocHelpers::SignalData<void(QValue3DAxis *)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 10 },
        }}),
        // Signal 'columnAxisChanged'
        QtMocHelpers::SignalData<void(QCategory3DAxis *)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'multiSeriesUniformChanged'
        QtMocHelpers::SignalData<void(bool)>(14, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Signal 'barThicknessChanged'
        QtMocHelpers::SignalData<void(float)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 17 },
        }}),
        // Signal 'barSpacingChanged'
        QtMocHelpers::SignalData<void(const QSizeF &)>(18, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 19, 20 },
        }}),
        // Signal 'barSpacingRelativeChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Signal 'barSeriesMarginChanged'
        QtMocHelpers::RevisionedSignalData<void(const QSizeF &)>(23, 8, QMC::AccessPublic, 0x603, QMetaType::Void, {{
            { 0x80000000 | 19, 24 },
        }}),
        // Signal 'meshFileNameChanged'
        QtMocHelpers::SignalData<void(const QString &)>(25, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Signal 'primarySeriesChanged'
        QtMocHelpers::SignalData<void(QBar3DSeries *)>(27, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Signal 'selectedSeriesChanged'
        QtMocHelpers::SignalData<void(QBar3DSeries *)>(30, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Signal 'floorLevelChanged'
        QtMocHelpers::RevisionedSignalData<void(float)>(31, 8, QMC::AccessPublic, 0x102, QMetaType::Void, {{
            { QMetaType::Float, 32 },
        }}),
        // Slot 'handleAxisXChanged'
        QtMocHelpers::SlotData<void(QAbstract3DAxis *)>(33, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 10 },
        }}),
        // Slot 'handleAxisYChanged'
        QtMocHelpers::SlotData<void(QAbstract3DAxis *)>(35, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 10 },
        }}),
        // Slot 'handleAxisZChanged'
        QtMocHelpers::SlotData<void(QAbstract3DAxis *)>(36, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 34, 10 },
        }}),
        // Method 'addSeries'
        QtMocHelpers::MethodData<void(QBar3DSeries *)>(37, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Method 'removeSeries'
        QtMocHelpers::MethodData<void(QBar3DSeries *)>(38, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Method 'insertSeries'
        QtMocHelpers::MethodData<void(int, QBar3DSeries *)>(39, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 40 }, { 0x80000000 | 28, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'rowAxis'
        QtMocHelpers::PropertyData<QCategory3DAxis*>(41, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'valueAxis'
        QtMocHelpers::PropertyData<QValue3DAxis*>(42, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'columnAxis'
        QtMocHelpers::PropertyData<QCategory3DAxis*>(43, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'multiSeriesUniform'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'barThickness'
        QtMocHelpers::PropertyData<float>(45, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'barSpacing'
        QtMocHelpers::PropertyData<QSizeF>(46, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'barSpacingRelative'
        QtMocHelpers::PropertyData<bool>(47, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'barSeriesMargin'
        QtMocHelpers::PropertyData<QSizeF>(48, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7, 0x603),
        // property 'seriesList'
        QtMocHelpers::PropertyData<QQmlListProperty<QBar3DSeries>>(2, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'selectedSeries'
        QtMocHelpers::PropertyData<QBar3DSeries*>(50, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'primarySeries'
        QtMocHelpers::PropertyData<QBar3DSeries*>(51, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 9),
        // property 'floorLevel'
        QtMocHelpers::PropertyData<float>(52, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11, 0x102),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<DeclarativeBars, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DeclarativeBars::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractDeclarative::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DeclarativeBarsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DeclarativeBarsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15DeclarativeBarsE_t>.metaTypes,
    nullptr
} };

void DeclarativeBars::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DeclarativeBars *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->rowAxisChanged((*reinterpret_cast<std::add_pointer_t<QCategory3DAxis*>>(_a[1]))); break;
        case 1: _t->valueAxisChanged((*reinterpret_cast<std::add_pointer_t<QValue3DAxis*>>(_a[1]))); break;
        case 2: _t->columnAxisChanged((*reinterpret_cast<std::add_pointer_t<QCategory3DAxis*>>(_a[1]))); break;
        case 3: _t->multiSeriesUniformChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->barThicknessChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 5: _t->barSpacingChanged((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1]))); break;
        case 6: _t->barSpacingRelativeChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->barSeriesMarginChanged((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1]))); break;
        case 8: _t->meshFileNameChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->primarySeriesChanged((*reinterpret_cast<std::add_pointer_t<QBar3DSeries*>>(_a[1]))); break;
        case 10: _t->selectedSeriesChanged((*reinterpret_cast<std::add_pointer_t<QBar3DSeries*>>(_a[1]))); break;
        case 11: _t->floorLevelChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 12: _t->handleAxisXChanged((*reinterpret_cast<std::add_pointer_t<QAbstract3DAxis*>>(_a[1]))); break;
        case 13: _t->handleAxisYChanged((*reinterpret_cast<std::add_pointer_t<QAbstract3DAxis*>>(_a[1]))); break;
        case 14: _t->handleAxisZChanged((*reinterpret_cast<std::add_pointer_t<QAbstract3DAxis*>>(_a[1]))); break;
        case 15: _t->addSeries((*reinterpret_cast<std::add_pointer_t<QBar3DSeries*>>(_a[1]))); break;
        case 16: _t->removeSeries((*reinterpret_cast<std::add_pointer_t<QBar3DSeries*>>(_a[1]))); break;
        case 17: _t->insertSeries((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QBar3DSeries*>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QCategory3DAxis* >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QValue3DAxis* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QCategory3DAxis* >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBar3DSeries* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBar3DSeries* >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstract3DAxis* >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstract3DAxis* >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAbstract3DAxis* >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBar3DSeries* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBar3DSeries* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QBar3DSeries* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(QCategory3DAxis * )>(_a, &DeclarativeBars::rowAxisChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(QValue3DAxis * )>(_a, &DeclarativeBars::valueAxisChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(QCategory3DAxis * )>(_a, &DeclarativeBars::columnAxisChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(bool )>(_a, &DeclarativeBars::multiSeriesUniformChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(float )>(_a, &DeclarativeBars::barThicknessChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(const QSizeF & )>(_a, &DeclarativeBars::barSpacingChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(bool )>(_a, &DeclarativeBars::barSpacingRelativeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(const QSizeF & )>(_a, &DeclarativeBars::barSeriesMarginChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(const QString & )>(_a, &DeclarativeBars::meshFileNameChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(QBar3DSeries * )>(_a, &DeclarativeBars::primarySeriesChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(QBar3DSeries * )>(_a, &DeclarativeBars::selectedSeriesChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (DeclarativeBars::*)(float )>(_a, &DeclarativeBars::floorLevelChanged, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 10:
        case 9:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QBar3DSeries* >(); break;
        case 2:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QCategory3DAxis* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QValue3DAxis* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QCategory3DAxis**>(_v) = _t->rowAxis(); break;
        case 1: *reinterpret_cast<QValue3DAxis**>(_v) = _t->valueAxis(); break;
        case 2: *reinterpret_cast<QCategory3DAxis**>(_v) = _t->columnAxis(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isMultiSeriesUniform(); break;
        case 4: *reinterpret_cast<float*>(_v) = _t->barThickness(); break;
        case 5: *reinterpret_cast<QSizeF*>(_v) = _t->barSpacing(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isBarSpacingRelative(); break;
        case 7: *reinterpret_cast<QSizeF*>(_v) = _t->barSeriesMargin(); break;
        case 8: *reinterpret_cast<QQmlListProperty<QBar3DSeries>*>(_v) = _t->seriesList(); break;
        case 9: *reinterpret_cast<QBar3DSeries**>(_v) = _t->selectedSeries(); break;
        case 10: *reinterpret_cast<QBar3DSeries**>(_v) = _t->primarySeries(); break;
        case 11: *reinterpret_cast<float*>(_v) = _t->floorLevel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setRowAxis(*reinterpret_cast<QCategory3DAxis**>(_v)); break;
        case 1: _t->setValueAxis(*reinterpret_cast<QValue3DAxis**>(_v)); break;
        case 2: _t->setColumnAxis(*reinterpret_cast<QCategory3DAxis**>(_v)); break;
        case 3: _t->setMultiSeriesUniform(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setBarThickness(*reinterpret_cast<float*>(_v)); break;
        case 5: _t->setBarSpacing(*reinterpret_cast<QSizeF*>(_v)); break;
        case 6: _t->setBarSpacingRelative(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setBarSeriesMargin(*reinterpret_cast<QSizeF*>(_v)); break;
        case 10: _t->setPrimarySeries(*reinterpret_cast<QBar3DSeries**>(_v)); break;
        case 11: _t->setFloorLevel(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DeclarativeBars::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeclarativeBars::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15DeclarativeBarsE_t>.strings))
        return static_cast<void*>(this);
    return AbstractDeclarative::qt_metacast(_clname);
}

int DeclarativeBars::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractDeclarative::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void DeclarativeBars::rowAxisChanged(QCategory3DAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void DeclarativeBars::valueAxisChanged(QValue3DAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void DeclarativeBars::columnAxisChanged(QCategory3DAxis * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void DeclarativeBars::multiSeriesUniformChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void DeclarativeBars::barThicknessChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void DeclarativeBars::barSpacingChanged(const QSizeF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void DeclarativeBars::barSpacingRelativeChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void DeclarativeBars::barSeriesMarginChanged(const QSizeF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void DeclarativeBars::meshFileNameChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void DeclarativeBars::primarySeriesChanged(QBar3DSeries * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void DeclarativeBars::selectedSeriesChanged(QBar3DSeries * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void DeclarativeBars::floorLevelChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
